@@ -133,7 +133,7 @@ impl PrintItems {
               text.push_str(&get_items_as_text(false_path, format!("{}    ", &indent_text)));
             }
           }
-          PrintItem::String(str_text) => text.push_str(&get_line(format!("`{}`", str_text.text.to_string()), &indent_text)),
+          PrintItem::String(str_text) => text.push_str(&get_line(format!("`{}`", str_text.text), &indent_text)),
           PrintItem::RcPath(path) => text.push_str(&get_items_as_text(path, indent_text.clone())),
         }
       }
