@@ -142,8 +142,8 @@ fn gen_node(node: Node) -> PrintItems {
   // in a real implementation this function would deal with surrounding comments
 
   match node {
-    Node::ArrayLiteralExpression(expr) => gen_array_literal_expression(&expr),
-    Node::ArrayElement(array_element) => gen_array_element(&array_element),
+    Node::ArrayLiteralExpression(expr) => gen_array_literal_expression(expr),
+    Node::ArrayElement(array_element) => gen_array_element(array_element),
   }
 }
 
@@ -167,7 +167,7 @@ fn gen_array_literal_expression(expr: &ArrayLiteralExpression) -> PrintItems {
   items.push_condition(conditions::if_true_or(
     "indentIfMultipleLines",
     is_multiple_lines.clone(),
-    ir_helpers::with_indent(generated_elements.clone().into()),
+    ir_helpers::with_indent(generated_elements.into()),
     generated_elements.into(),
   ));
 
@@ -178,7 +178,7 @@ fn gen_array_literal_expression(expr: &ArrayLiteralExpression) -> PrintItems {
 
   return items;
 
-  fn gen_elements(elements: &Vec<ArrayElement>, is_multiple_lines: &(impl Fn(&mut ConditionResolverContext) -> Option<bool> + Clone + 'static)) -> PrintItems {
+  fn gen_elements(elements: &[ArrayElement], is_multiple_lines: &(impl Fn(&mut ConditionResolverContext) -> Option<bool> + Clone + 'static)) -> PrintItems {
     let mut items = PrintItems::new();
     let elements_len = elements.len();
 
@@ -214,9 +214,9 @@ fn create_is_multiple_lines_resolver(
 ) -> impl Fn(&mut ConditionResolverContext) -> Option<bool> + Clone + 'static {
   // todo: this could be more efficient only only use references and avoid the clones
   // I'm too lazy to update this sample, but it should help you get the idea.
-  return move |condition_context: &mut ConditionResolverContext| {
+  move |condition_context: &mut ConditionResolverContext| {
     // no items, so format on the same line
-    if child_positions.len() == 0 {
+    if child_positions.is_empty() {
       return Some(false);
     }
     // first child is on a different line than the start of the parent
@@ -227,5 +227,5 @@ fn create_is_multiple_lines_resolver(
 
     // check if it spans multiple lines, and if it does then make it multi-line
     condition_resolvers::is_multiple_lines(condition_context, &start_info, &end_info)
-  };
+  }
 }
